disp('Square block under compression, with no slip condition of the top and bottom; t3 fully integrated');

% Parameters:
E=1e7;
% nu=0.49992;
nu=0.45;
integration_order=1;

% Mesh
% [fens,gcells] = squar;
% for i=1:length(fens)
%     xy=get(fens(i),'xyz');
%     xy=xy+1;
%     fens(i)=set(fens(i),'xyz',xy);
% end
n=4;
[fens,gcells] = t3block2d(2,2, n, n, 1.0);
% mesh{1}=fens;
% mesh{2}=gcells;
% drawmesh(mesh); pause

% Material
mater = mater_defor_ss_linel_iso_biax (struct('E',E,'nu',nu,'type', ['strain']));
% Finite element block
feb = feblock_defor_ss (struct('mater',mater, 'gcells',gcells,...
    'integration_rule',tri_rule (integration_order)));
% Geometry
geom = field(struct ('name',['geom'], 'dim', 2, 'fens',fens));
% Define the displacement field
u   = clone(geom,'u');
u   = u*0; % zero out

% Apply EBC's
% First the punch of the top
ebc_fenids=fenode_select (fens,struct('box',[0.0 2.0 2.0 2.0]));
ebc_prescribed=ones(1,length (ebc_fenids));
ebc_comp=2*ones(1,length (ebc_fenids));
ebc_val=ebc_fenids*0-0.4;
u   = set_ebc(u, ebc_fenids, ebc_prescribed, ebc_comp, ebc_val);
ebc_comp=ones(1,length (ebc_fenids));
ebc_val=ebc_fenids*0;
u   = set_ebc(u, ebc_fenids, ebc_prescribed, ebc_comp, ebc_val);
u   = apply_ebc (u);
% finally, the symmetry boundary conditions
ebc_fenids=fenode_select (fens,struct('box',[0.0 0.0 0.0 2.0]));
ebc_prescribed=ones(1,length (ebc_fenids));
ebc_comp=ones(1,length (ebc_fenids));
ebc_val=ebc_fenids*0;
u   = set_ebc(u, ebc_fenids, ebc_prescribed, ebc_comp, ebc_val);
u   = apply_ebc (u);
ebc_fenids=fenode_select (fens,struct('box',[0.0 2.0 0.0 0.0]));
ebc_prescribed=ones(1,length (ebc_fenids));
ebc_comp=ones(1,length (ebc_fenids))+1;
ebc_val=ebc_fenids*0;
u   = set_ebc(u, ebc_fenids, ebc_prescribed, ebc_comp, ebc_val);
u   = apply_ebc (u);
% Number equations
u   = numbereqns (u);
% Assemble the system matrix
ems = stiffness(feb, geom, u);
K = sparse_sysmat;
K = start (K, get(u, 'neqns'));
K = assemble (K, ems);
K = finish (K);
% Load
F = sysvec;
F = start (F, get(u, 'neqns'));
evs = nz_ebc_loads(feb, geom, u);
F = assemble (F, evs);
F = finish(F);
% Solve
a = get(K,'mat');
b = get(F,'vec');
x = a\b;
u = scatter_sysvec(u, x);
% get(u,'values')
nl=fenode_select (fens,struct ('box',[2.0 2.0 0.0 0.0],'inflate',0.0001));
eqn=gather (u,nl,'eqnums');
disp(['Horizontal deflection: ' num2str(x(eqn(1)))])

% Plot
gv=graphic_viewer;
gv=reset (gv,struct ('limits',[0.0 3.0 0.0 2.0]));
scale=1;
cmap = jet;
fld = field_from_integration_points(feb, geom, u, [], 'vol_strain', 1);
nvals=get(fld,'values');%min(nvals),max(nvals)
% nvalsrange=[-0.0001 0.0001];%[min(nvals),max(nvals)]
nvalsrange=[min(nvals),max(nvals)];
dcm=data_colormap(struct ('range',nvalsrange, 'colormap',cmap));
colorfield=field(struct ('name', ['colorfield'], 'data',map_data(dcm, nvals)));
draw(feb,gv, struct ('x', geom, 'u', +scale*u,'colorfield',colorfield, 'shrink',1.0));
% geom3d=combine (geom, 0*fld);
% u3d=combine (u, 100000000*fld);
% draw(feb,gv, struct ('x', geom3d, 'u', +scale*u3d,'colorfield',colorfield, 'shrink',1.0));
colormap(cmap);
cbh=colorbar;
set(cbh,...
    'Position',[0.8 0.15 0.05 0.7],...
    'YLim',[0,1],...
    'YTick',[0,1],...
    'YTickLabel',{[num2str(nvalsrange(1))],[num2str(nvalsrange(2))]});%{[num2str((min(nvals)))],[num2str((max(nvals)))]}
set(get(cbh,'XLabel'),'String','Volumetric strain');
view (2)
