disp('tapered strip: q4 elements');

% Parameters:
E=1e7;
nu=0.3;
integration_order=2;
P=1;
graphics = ~true;

% Mesh
L=20;
c=2;
nel=[];
mxsig=[];
se=[];
n=[];
for N=[1 2 4 8 16]
    n=[n N];
    [fens,gcells] = block2d(L,2*c, 3*N, N, 1.0);
    disp([num2str(length(gcells)) ' elements'])
    for i=1:length(fens)
        xy=get(fens(i),'xyz');
        xy(2)=xy(2) + (xy(1)>L/3)*(xy(1)<=2*L/3)*0.05*(xy(1)-L/3)*xy(2) + (xy(1)>2*L/3)*0.05*(L/3)*xy(2);
        fens(i)=set(fens(i),'xyz',xy);
    end

    % Material
    mater = mater_defor_ss_linelastic_biax (struct ('E',E,'nu',nu,'type',['strain']));
    % Finite element block
    feb = feblock_defor_ss_biax (struct ('mater',mater, 'gcells',gcells, 'integration_rule',gauss_rule (2, integration_order)));
    % Geometry
    geom = field(struct ('name',['geom'], 'dim', 2, 'fens',fens));
    % Define the displacement field
    u   = clone(geom,'u');
    u   = u*0; % zero out
    % Apply EBC's
    ebc_fenids=fenode_select (fens,struct('box',[0 L 0 0],'inflate', 0.0001));
    ebc_prescribed=ones(1,length (ebc_fenids));
    ebc_comp=ebc_fenids*0+2;
    ebc_val=ebc_fenids*0;
    u   = set_ebc(u, ebc_fenids, ebc_prescribed, ebc_comp, ebc_val);
    ebc_fenids=fenode_select (fens,struct('box',[0 0 0 100*c],'inflate', 0.0001));
    ebc_prescribed=ones(1,length (ebc_fenids));
    ebc_comp=ebc_fenids*0+1;
    ebc_val=ebc_fenids*0;
    u   = set_ebc(u, ebc_fenids, ebc_prescribed, ebc_comp, ebc_val);
    ebc_fenids=fenode_select (fens,struct('box',[L L 0 100*c],'inflate', 0.0001));
    ebc_prescribed=ones(1,length (ebc_fenids));
    ebc_comp=ebc_fenids*0+1;
    ebc_val=ebc_fenids*0+c;
    u   = set_ebc(u, ebc_fenids, ebc_prescribed, ebc_comp, ebc_val);
    u   = apply_ebc (u);
    % Number equations
    u   = numbereqns (u);
    % Assemble the system matrix
    ems = stiffness(feb, geom, u);
    K = sparse_sysmat;
    K = start (K, get(u, 'neqns'));
    K = assemble (K, ems);
    K = finish (K);
    Kmat=get(K,'mat');
    % Load
    F = start (sysvec, get(u, 'neqns'));
    evs = nz_ebc_loads(feb, geom, u);
    F = assemble (F, evs);
    F = finish(F);
    Fmat=get(F,'vec');
    % Solve
    sol=bicg(Kmat,Fmat,1e-6,3000,diag(diag(Kmat)));
    u = scatter_sysvec(u, sol);

    % Plot
    scale=1;
    if graphics
        gv=graphic_viewer;
        gv=reset (gv,struct ('limits', [0 1.2*L 0 4*c]));
        draw(feb,gv, struct ('x', geom, 'u',u, 'facecolor','none'));
    end
    nel=[nel length(gcells)];
    max_sigma=inspect_integration_points(feb, geom, u, [], (1:length (gcells)), struct ('output',['Cauchy']),...
        inline('max(out(1), inspector_data)','inspector_data','out','xyz'),...
        -Inf);
    min_sigma=inspect_integration_points(feb, geom, u, [], (1:length (gcells)), struct ('output',['Cauchy']),...
        inline('min(out(1), inspector_data)','inspector_data','out','xyz'),...
        Inf);
    mxsig=[mxsig max_sigma];
    se=[se strain_energy(feb, geom, u)];
    if graphics
        dcm=data_colormap(struct ('range',[min_sigma, max_sigma], 'colormap',jet));
        for i=1:length(gcells)
            sigma=inspect_integration_points(feb, geom, u, [], i, struct ('output',['Cauchy']),...
                inline('min(out(1), inspector_data)','inspector_data','out','xyz'),...
                Inf);
            draw(gcells (i),gv, struct ('x', geom, 'u',scale*u, 'facecolor',map_data (dcm, sigma)));
        end
        colormap(jet);
        cbh=colorbar;
        set(cbh,...
            'Position',[0.2 0.75 0.5 0.2],...
            'YLim',[0,1],...
            'YTick',[0,1],...
            'YTickLabel',{[num2str(min_sigma)],[num2str(max_sigma)]});%{[num2str((min(nvals)))],[num2str((max(nvals)))]}
        set(get(cbh,'XLabel'),'String','Tensile stress');
        view (2)
    end
    if ~graphics
        plot(nel,se,'ro-');
        figure(gcf);
    end
    pause(1)
end